# Summary

<!-- Describe in detail what your change does and why. -->

## Merge Request Checklist

<!--
- Read our [contribution guide](https://github.com/tahv/hed/blob/main/CONTRIBUTING.md).
- If an item doesn't apply, **check it anyway**
  to make it apparent that there's nothing left to do.
- If the change is trivial, feel free to delete the whole thing.
-->

- [ ] Updated **tests** for changed code.
- [ ] Updated **documentation** for changed code.
- [ ] Changes have **news fragments** in
  [`changelog.d`](https://github.com/tahv/hed/blob/main/changelog.d).
